@@ -20,10 +20,6 @@
 
 int main(int argc, char *argv[])
 {
-	// Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
 	KLocalizedString::setApplicationDomain("kiriki");
@@ -36,15 +32,18 @@ int main(int argc, char *argv[])
             QStringLiteral("https://apps.kde.org/kiriki"));
 	about.addAuthor(i18n("Albert Astals Cid"), QString(), QStringLiteral("aacid@kde.org"));
 
-	QCommandLineParser parser;
 	KAboutData::setApplicationData(about);
+	QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kiriki")));
+
 	KCrash::initialize();
+
+	QCommandLineParser parser;
 	about.setupCommandLine(&parser);
 	parser.process(app);
 	about.processCommandLine(&parser);
+
 	KDBusService service;
 	kiriki *w = new kiriki();
 	w->show();
-	app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kiriki")));
 	return app.exec();
 }
